@@ -10,6 +10,23 @@
 #' @return Matrix of 3 columns if \code{add_values = FALSE} or 4 columns, 
 #' otherwise.
 #' @export
+#' @examples 
+#' set.seed(5)
+#' dims = rep(10, 4)
+#' arr = array(rpois(prod(dims), lambda = 2), dim = dims)
+#' nim = oro.nifti::nifti(arr)
+#' ind = img_indices(nim)
+#' ind2 = img_indices(nim, mask = nim > 2)
+#' # 3d example
+#' set.seed(5)
+#' dims = rep(10, 3)
+#' arr = array(rpois(prod(dims), lambda = 2), dim = dims)
+#' nim = oro.nifti::nifti(arr)
+#' ind = img_indices(nim)
+#' ind2 = img_indices(nim, mask = nim > 2)
+#' testthat::expect_equal(colnames(ind2), c("x", "y", "z"))
+#' ind2 = img_indices(nim, mask = nim > 2, add_values = TRUE)
+#' testthat::expect_equal(colnames(ind2), c("x", "y", "z", "value"))
 img_indices <- function(img, mask = NULL, 
                         add_values = FALSE,
                         units = c("index", "mm")){
@@ -38,7 +55,7 @@ img_indices <- function(img, mask = NULL,
     }
     df = t( t(df) * vdim )
   }
-  colnames(df) <- c("x", "y", "z")
+  colnames(df) <- c("x", "y", "z", "t")[ 1:ncol(df) ]
   df = cbind(df, value = vals)
   df
 }
